@@ -6,6 +6,7 @@ class BaseNormalize(object):
     def normalize(self, ex, exc_class=None, **kwargs):
         """
         Child class must return super().normalize() so as to keep the chain of Mixins
+
         :param ex: input exception
         :param exc_class: class of output exception
         :return:
@@ -40,8 +41,11 @@ class MethodNotAllowedMixin(BaseNormalize):
         :return:
         """
         if isinstance(ex, MethodNotAllowed):
-            ex.response = dict(Allow=ex.valid_methods)
-            ex.headers = dict(Allow=", ".join(ex.valid_methods))
+            try:
+                ex.headers = dict(Allow=", ".join(ex.valid_methods))
+                ex.response = dict(Allow=ex.valid_methods)
+            except TypeError:
+                pass
 
         return super().normalize(ex, exc_class)
 
@@ -53,6 +57,7 @@ class DefaultNormalizeMixin(
     def normalize(self, ex, exc_class=None, **kwargs):
         """
         Collects the default normalize Mixins used in ErrorHandler
+
         :param ex:
         :param exc_class:
         :param kwargs:
